#include "stdafx.h"
#include "FileTypeDeterminer.hpp"
#include <harkio2/harkio.hpp>

using namespace std;

namespace
{

/** @brief XMLファイルの詳しい種類を判別する.
 * HARK-config形式のXMLファイルを対象として、
 * ImpulseResponseListFile, TSPListFile, MicArrayLocationFile, NoiseLocationFile
 * のどれかを判別する.
 * @param file_name XMLファイル名
 * @return ファイルの種類
 */
harktool4::FileType DetermineXml(const std::string& file_name)
{
    using namespace harktool4;
    try
    {
        auto xml_reader = harkio2::harkconfig::HarkConfigFileXMLReader(file_name);
        auto hark_config = xml_reader.Read();

        auto id = hark_config->GetId();
        if (id == "ImpulseResponseListFile")
        {
            return FileType::XML_IR;
        }
        else if (id == "TSPListFile")
        {
            return FileType::XML_TSP;
        }
        else if (id == "MicArrayLocationFile")
        {
            return FileType::XML_MIC;
        }
        else if (id == "NoiseLocationFile")
        {
            return FileType::XML_NOISE;
        }
    }
    catch (const harkio2::AnalyzeError& e)
    {
        return FileType::UNKNOWN;
    }

    return FileType::UNKNOWN;
}

}

namespace harktool4
{

FileType FileTypeDeterminer::Determine(const std::string& file_name) const
{
    auto dot_pos = file_name.rfind('.');

    if (dot_pos != string::npos)
    {
        auto ext = file_name.substr(dot_pos + 1);
        if (ext == "wav")
        {
            return FileType::WAVE;
        }
        else if (ext == "flt")
        {
            return FileType::FLOAT_ARRAY;
        }
        else
        {
            return DetermineXml(file_name);
        }
    }

    return FileType::UNKNOWN;
}

}

